// Последнее обновление 2017-05-31 by Phisik
// В рамках разгрузки кода раскидываем функции по файлам
// Тут мы работаем с EEPROM

#include "configuration.h"
#include "declarations.h"

unsigned int ee_addr; // Переменная для хранения текущего адреса чтения/записи в EEPROM
unsigned char eeReadChar()
{
  unsigned char lByte = EEPROM.read(ee_addr);
  ee_addr++;
  return lByte;
}

void eeWriteChar(char p_value)
{
  if (EEPROM.read(ee_addr) != p_value)
    EEPROM.write(ee_addr, p_value);
  ee_addr++;
}

void eeWriteInt(int p_value)
{
  unsigned char lByte = (unsigned char) (p_value);
  unsigned char hByte = (unsigned char) (p_value >> 8);

  // Для экономии ресурса флеш памяти, сначала проверяем ее содержимое и запись производим только если значение отличается.
  eeWriteChar(lByte);
  eeWriteChar(hByte);
}

//This function will read a 2 byte integer from the eeprom at the specified address and address + 1
unsigned int eeReadInt()
{
  unsigned char lByte = eeReadChar();
  unsigned char hByte = eeReadChar();
  return (unsigned int) (lByte) | (unsigned int)  (hByte << 8);
}

void writeEEPROM()
{
  int i;
  flAutoDetectPowerTEN = 0;
  ee_addr = 0;
  eeWriteChar(PR_REWRITE_EEPROM);
  eeWriteChar(IspReg);
  eeWriteInt(Power);
  eeWriteInt(UstPowerReg);
  eeWriteInt(TempTerm);
  eeWriteInt(Delta);
  eeWriteChar(FlToUSART);
  eeWriteInt(Temp1P);
  eeWriteInt(Temp2P);
  eeWriteInt(Temp3P);
  for (i = 0; i < MAX_DS1820; i++)
  
  eeWriteChar(ds1820_popr[i]);
  eeWriteInt(PowerDistil);
  eeWriteInt(TempDeflBegDistil);
  eeWriteChar(BeepEndProcess);
  eeWriteChar(BeepStateProcess);
  eeWriteChar(BeepKeyPress);

  eeWriteInt(PowerTermostat);

  eeWriteChar(CorrectASC712);
  eeWriteChar(PIDTemp[0]);
  eeWriteChar(PIDTemp[1]);
  eeWriteChar(PIDTemp[2]);

  eeWriteInt(Power);

}

void readEEPROM()
{
  int i;
  unsigned char ctmp;
  ee_addr = 0;
  eeReadChar();
  IspReg = eeReadChar();
  Power = eeReadInt();
  UstPowerReg = eeReadInt();
  TempTerm = eeReadInt();
  Delta = eeReadInt();
  FlToUSART = eeReadChar();
  Temp1P = eeReadInt();
  Temp2P = eeReadInt();
  Temp3P = eeReadInt();
  for (i = 0; i < MAX_DS1820; i++)
    ds1820_popr[i] = eeReadChar();
  PowerDistil = eeReadInt();
  TempDeflBegDistil = eeReadInt();
  BeepEndProcess = eeReadChar();
  BeepStateProcess = eeReadChar();
  BeepKeyPress = eeReadChar();

  PowerTermostat = eeReadInt();

  CorrectASC712 = eeReadChar();
  if (CorrectASC712 == -1) CorrectASC712 = 0;

  PIDTemp[0] = eeReadChar();
  PIDTemp[1] = eeReadChar();
  PIDTemp[2] = eeReadChar();
  if (PIDTemp[0] == -1)
  {
    PIDTemp[0] = 20;
    PIDTemp[1] = 10;
    PIDTemp[2] = 30;
  }

  Power = eeReadInt();
  if (Power < 0 || Power > 10000) Power = Power;

  PIDTime == eeReadChar();
  if (PIDTime == 255) PIDTime = 15;

}
